@@ -34,9 +34,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 \n\
 By: Paul Wilkins\n\
     paul.wilkins at analog com\n\
-    fix_locale.dpatch by Wartan Hachaturow <wart at debian.org>\n\
-    add_includes.dpatch by Michael Bienia <geser at ubuntu.com>\n\
+    Fix_locale.dpatch by Wartan Hachaturow <wart at debian.org>\n\
+    Add_includes.dpatch by Michael Bienia <geser at ubuntu.com>\n\
     gtk2.dpatch by Barry deFreese <bdefreese at debian.org>\n\
+    Support for Pango-fonts by Jean-Pierre Demailly.\n\
+    Shift operators by Nathaniel Clark.\n\
     Changes since version 1.1.2-3: Jens Getreu <getreu at web.de>\n\
 \n\
 "
@@ -168,8 +170,6 @@ void popup_window(GtkWidget **dialog, char *txt, char *title){
       gtk_widget_show(scrolled_win);
 
       label = gtk_label_new(txt);
-      gtk_signal_connect(GTK_OBJECT(label), "destroy",
-                          GTK_SIGNAL_FUNC(gtk_widget_destroyed), &label);
       gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 #ifdef GTK_VER_1_1
       gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_win), label);
